==> haskell-concise-0.1.0.1-654-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-LfX519rySSIKHEY9d2azgz
key:                  concise-0.1.0.1-LfX519rySSIKHEY9d2azgz
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  5b5febb2e6c3addc6487fdb16f561a02
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-LfX519rySSIKHEY9d2azgz
depends:
    base-4.18.2.1 bytestring-0.11.5.3 lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-655-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-BF60INhOvBr4m1zcbZgeFM
key:                  concise-0.1.0.1-BF60INhOvBr4m1zcbZgeFM
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  c358f907786ed3b9757b779a0bd923ed
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-BF60INhOvBr4m1zcbZgeFM
depends:
    base-4.18.2.1 bytestring-0.11.5.3 lens-5.3.3-KFcjpRU85K93uhgNXhcmM2
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
